@@ -11,11 +11,10 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from __future__ import absolute_import, division, print_function
 
 import re
 import warnings
-from typing import Any, Match, Optional
+from typing import cast, Any, Dict, Callable, Match, Optional
 
 from html import unescape
 
@@ -33,13 +32,13 @@ _EXTRA_WARNING = (
 try:
     import cmarkgfm
     from cmarkgfm.cmark import Options as cmarkgfmOptions
-    variants = {
-        "GFM": lambda raw: cmarkgfm.github_flavored_markdown_to_html(
+    variants: Dict[str, Callable[[str], str]] = {
+        "GFM": lambda raw: cast(str, cmarkgfm.github_flavored_markdown_to_html(
             raw, options=cmarkgfmOptions.CMARK_OPT_UNSAFE
-        ),
-        "CommonMark": lambda raw: cmarkgfm.markdown_to_html(
+        )),
+        "CommonMark": lambda raw: cast(str, cmarkgfm.markdown_to_html(
             raw, options=cmarkgfmOptions.CMARK_OPT_UNSAFE
-        ),
+        )),
     }
 except ImportError:
     warnings.warn(_EXTRA_WARNING)
@@ -66,8 +65,7 @@ def render(
     if not renderer:
         return None
 
-    # The renderer is a lambda function, and mypy fails lambdas right now.
-    rendered = renderer(raw)  # type: ignore
+    rendered = renderer(raw)
 
     if not rendered:
         return None
@@ -118,7 +116,7 @@ def _highlight(html: str) -> str:
 
         highlighted = pygments.highlight(code, lexer, formatter)
 
-        return '<pre>{}</pre>'.format(highlighted)
+        return f'<pre lang="{lang}">{highlighted}</pre>'
 
     result = code_expr.sub(replacer, html)
 
